window.Gleam.initSearch([{"doc":"clamav_client","title":"clamav_client","content":"# clamav_client\n\n[![Package Version](https://img.shields.io/hexpm/v/clamav_client)](https://hex.pm/packages/clamav_client)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/clamav_client/)\n[![Latest CI](https://github.com/alexdeane/gleam-clamav/actions/workflows/test.yml/badge.svg)](https://github.com/alexdeane/gleam-clamav/actions/workflows/test.yml)\n\nGleam client for interacting with a [ClamAV](https://www.clamav.net/) instance\n\n```sh\ngleam add clamav_client@1\n```\n```gleam\nimport clamav_client/clamav\n\npub fn main() {\n  let data = &quot;some data, probably a file&quot; |&gt; bit_array.from_string\n\n  let clamav_options =\n    clamav.new(&quot;&lt;host&gt;&quot;)\n    |&gt; clamav.port(3310)\n\n  case clamav.instream(clamav_options, data) {\n    Ok(Clean) -&gt; &quot;Clean!&quot;\n    Ok(VirusDetected(infected_files)) -&gt; {\n      let infected_file =\n        infected_files |&gt; list.first\n\n      &quot;VirusDetected: &quot; &lt;&gt; infected_file.file_name &lt;&gt; &quot; | &quot; &lt;&gt; infected_file.virus_name\n    }\n    Error(error) -&gt; &quot;Error: &quot; &lt;&gt; error |&gt; string.inspect\n  }\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/clamav_client&gt;.\n","url":"index.html"},{"doc":"client_options","title":"ClamAvClientOptions","content":"pub type ClamAvClientOptions {\n  ClamAvClientOptions(\n    host: String,\n    port: Int,\n    connection_timeout: Int,\n    reply_timeout: Int,\n    logger: Logger,\n  )\n}\n Options for the ClamAV client\nClamAvClientOptions(\n  host: String,\n  port: Int,\n  connection_timeout: Int,\n  reply_timeout: Int,\n  logger: Logger,\n)\n\n\nSynonyms:\nclient_options.ClamAvClientOptions\nclient_options ClamAvClientOptions","url":"client_options.html#ClamAvClientOptions"},{"doc":"client_options","title":"Logger","content":"pub type Logger {\n  Logger(\n    log_error: fn(String) -&gt; Nil,\n    log_warning: fn(String) -&gt; Nil,\n    log_info: fn(String) -&gt; Nil,\n  )\n}\n Logger interface for the ClamAV client to use.\n To disable logging, pass in the `nil_logger`\nLogger(\n  log_error: fn(String) -&gt; Nil,\n  log_warning: fn(String) -&gt; Nil,\n  log_info: fn(String) -&gt; Nil,\n)\n\n\nSynonyms:\nclient_options.Logger\nclient_options Logger","url":"client_options.html#Logger"},{"doc":"client_options","title":"nil_logger","content":"pub const nil_logger: Logger\n Logger which does not log anything\nSynonyms:\nclient_options.nil_logger\nclient_options nil_logger","url":"client_options.html#nil_logger"},{"doc":"client_options","title":"client_options","content":"","url":"client_options.html"},{"doc":"common/tcp","title":"connect","content":"pub fn connect(\n  options: ClamAvClientOptions,\n  callback: fn(Socket) -&gt; Result(a, Error),\n) -&gt; Result(a, Error)\n\nSynonyms:\ncommon/tcp.connect\ncommon/tcp connect","url":"common/tcp.html#connect"},{"doc":"common/tcp","title":"receive_bytes","content":"pub fn receive_bytes(\n  socket: Socket,\n  options: ClamAvClientOptions,\n  callback: fn(BitArray) -&gt; Result(a, Error),\n) -&gt; Result(a, Error)\n\nSynonyms:\ncommon/tcp.receive_bytes\ncommon/tcp receive_bytes","url":"common/tcp.html#receive_bytes"},{"doc":"common/tcp","title":"send_bytes","content":"pub fn send_bytes(\n  socket: Socket,\n  bits: BitArray,\n  options: ClamAvClientOptions,\n  callback: fn() -&gt; Result(a, Error),\n) -&gt; Result(a, Error)\n\nSynonyms:\ncommon/tcp.send_bytes\ncommon/tcp send_bytes","url":"common/tcp.html#send_bytes"},{"doc":"common/tcp","title":"common/tcp","content":"","url":"common/tcp.html"},{"doc":"common/internal","title":"execute_command","content":"pub fn execute_command(\n  options: ClamAvClientOptions,\n  command: String,\n  callback: fn(Socket) -&gt; Result(a, Error),\n) -&gt; Result(a, Error)\n\nSynonyms:\ncommon/internal.execute_command\ncommon/internal execute_command","url":"common/internal.html#execute_command"},{"doc":"common/internal","title":"common/internal","content":"","url":"common/internal.html"},{"doc":"clamav","title":"ClamError","content":"pub type ClamError {\n  ScanError(error: String)\n  CannotParseResponse(ClamResponseParsingError)\n  ConnectionError(error: mug.Error)\n}\n\nScanError(error: String)\n\n\nCannotParseResponse(ClamResponseParsingError)\n\n\nConnectionError(error: mug.Error)\n\n\nSynonyms:\nclamav.ClamError\nclamav ClamError","url":"clamav.html#ClamError"},{"doc":"clamav","title":"ClamResponseParsingError","content":"pub type ClamResponseParsingError {\n  UnexpectedResponse(raw_response: String)\n  InvalidBinaryData\n}\n\nUnexpectedResponse(raw_response: String)\n\n\nInvalidBinaryData\n\n\nSynonyms:\nclamav.ClamResponseParsingError\nclamav ClamResponseParsingError","url":"clamav.html#ClamResponseParsingError"},{"doc":"clamav","title":"ClamScanResult","content":"pub type ClamScanResult {\n  Clean\n  VirusDetected(infected_files: List(InfectedFile))\n}\n\nClean\n\n\nVirusDetected(infected_files: List(InfectedFile))\n\n\nSynonyms:\nclamav.ClamScanResult\nclamav ClamScanResult","url":"clamav.html#ClamScanResult"},{"doc":"clamav","title":"ClamVersionResponse","content":"pub type ClamVersionResponse {\n  ClamVersionResponse(version: String, database_version: String)\n}\n\nClamVersionResponse(version: String, database_version: String)\n\n\nSynonyms:\nclamav.ClamVersionResponse\nclamav ClamVersionResponse","url":"clamav.html#ClamVersionResponse"},{"doc":"clamav","title":"InfectedFile","content":"pub type InfectedFile {\n  InfectedFile(file_name: String, virus_name: String)\n}\n\nInfectedFile(file_name: String, virus_name: String)\n\n\nSynonyms:\nclamav.InfectedFile\nclamav InfectedFile","url":"clamav.html#InfectedFile"},{"doc":"clamav","title":"connection_timeout","content":"pub fn connection_timeout(\n  client: ClamAvClientOptions,\n  connection_timeout: Int,\n) -&gt; ClamAvClientOptions\n Configures the total connection timeout for the client to use. Defaults to 10s\nSynonyms:\nclamav.connection_timeout\nclamav connection_timeout","url":"clamav.html#connection_timeout"},{"doc":"clamav","title":"instream","content":"pub fn instream(\n  options: ClamAvClientOptions,\n  file_content: BitArray,\n) -&gt; Result(ClamScanResult, ClamError)\n Scan a file in memory\nSynonyms:\nclamav.instream\nclamav instream","url":"clamav.html#instream"},{"doc":"clamav","title":"logger","content":"pub fn logger(\n  client: ClamAvClientOptions,\n  logger: Logger,\n) -&gt; ClamAvClientOptions\n Configures a logger for the client to use. Defaults to a nil logger\nSynonyms:\nclamav.logger\nclamav logger","url":"clamav.html#logger"},{"doc":"clamav","title":"new","content":"pub fn new(host: String) -&gt; ClamAvClientOptions\n Creates a new instance of the client options\n given a host, with default values for the rest\nSynonyms:\nclamav.new\nclamav new","url":"clamav.html#new"},{"doc":"clamav","title":"ping","content":"pub fn ping(\n  options: ClamAvClientOptions,\n) -&gt; Result(Nil, ClamError)\n Send a PING command to the ClamAV server\nSynonyms:\nclamav.ping\nclamav ping","url":"clamav.html#ping"},{"doc":"clamav","title":"port","content":"pub fn port(\n  client: ClamAvClientOptions,\n  port: Int,\n) -&gt; ClamAvClientOptions\n Configures the port for the client to use. Defaults to 3310\nSynonyms:\nclamav.port\nclamav port","url":"clamav.html#port"},{"doc":"clamav","title":"reply_timeout","content":"pub fn reply_timeout(\n  client: ClamAvClientOptions,\n  reply_timeout: Int,\n) -&gt; ClamAvClientOptions\n Configures the timeout for awaiting a reply from the clam server. Defaults to 10s\nSynonyms:\nclamav.reply_timeout\nclamav reply_timeout","url":"clamav.html#reply_timeout"},{"doc":"clamav","title":"stats","content":"pub fn stats(\n  options: ClamAvClientOptions,\n) -&gt; Result(String, ClamError)\n\nSynonyms:\nclamav.stats\nclamav stats","url":"clamav.html#stats"},{"doc":"clamav","title":"version","content":"pub fn version(\n  options: ClamAvClientOptions,\n) -&gt; Result(ClamVersionResponse, ClamError)\n\nSynonyms:\nclamav.version\nclamav version","url":"clamav.html#version"},{"doc":"clamav","title":"clamav","content":"","url":"clamav.html"}]);